@@ -23,7 +23,7 @@
 // Google encoded polyline decoder
 // https://developers.google.com/maps/documentation/utilities/polylinealgorithm
 
-const Champlain = imports.gi.Champlain;
+import Shumate from 'gi://Shumate';
 
 function _decodeValue(data, index) {
     let b;
@@ -45,7 +45,7 @@ function _decodeValue(data, index) {
     return [ret_val, index];
 }
 
-function decode(data) {
+export function decode(data) {
     let length = data.length;
     let polyline = [];
     let index = 0;
@@ -61,7 +61,7 @@ function decode(data) {
         // first value is absolute, rest are relative to previous value
         lat += latdelta;
         lon += londelta;
-        polyline.push(new Champlain.Coordinate({
+        polyline.push(new Shumate.Coordinate({
             latitude:  lat * 1e-5,
             longitude: lon * 1e-5
         }));
